@@ -8,7 +8,7 @@ use base 'Test::More';
 use Test::More;
 use Term::ANSIColor;
 
-use version; our $VERSION = qv('0.3.2');
+use version; our $VERSION = qv('0.4.0');
 
 our @EXPORT = ( @Test::More::EXPORT, qw(describe context it) );
 
@@ -19,7 +19,7 @@ my $passed = 1;
 sub describe {
   $spec_desc = shift;
   my $block  = shift;
-  _evaluate_and_print($spec_desc, $block);
+  $block->();
   $spec_desc = undef;
 
   return;
@@ -28,7 +28,7 @@ sub describe {
 sub context {
   $context_desc = shift;
   my $block     = shift;
-  _evaluate_and_print($context_desc, $block);
+  $block->();
   $context_desc = undef;
 
   return;
@@ -45,25 +45,26 @@ sub it {
   return;
 }
 
-sub _evaluate_and_print {
+sub _evaluate_and_print_subtest {
   my $desc  = shift;
   my $block = shift;
-  $block->();
-  $desc     = undef;
-  return;
+
+  return _subtest(_construct_description($desc) => _subtest_block($block));
 }
 
-sub _evaluate_and_print_subtest {
-  my $description = shift;
-  my $block       = shift;
+sub _subtest {
+    my $desc  = shift;
+    my $block = shift;
 
-  return subtest _construct_description($description) => _subtest_block($block);
+    $block->();
+    print $desc->(),"\n";
+
+    return;
 }
 
 sub _subtest_block {
   my $block = shift;
   return sub {
-    plan 'no_plan';
     eval {
       $passed = $block->();
       1;
@@ -75,13 +76,12 @@ sub _subtest_block {
 }
 
 sub _construct_description {
-  my ($test_desc) = @_;
-  my $result = $test_desc;
+  my $result = shift;
 
-  $result = "$spec_desc\n\t $result" if $spec_desc and (! $context_desc);
-  $result = "$spec_desc\n\t $context_desc\n\t   $result" if $spec_desc and $context_desc;
+  $result = "$spec_desc\n  $result" if $spec_desc and (! $context_desc);
+  $result = "$spec_desc\n  $context_desc\n    $result" if $spec_desc and $context_desc;
 
-  return colored [$passed ? 'green' : 'red'], $result;
+  return sub { colored [$passed ? 'green' : 'red'], $result };
 }
 
 1;
